* Installation

```
pip install calibrated_regression  
```

* Usage

```
import calibrated_regression

calibrated_cases = calibrated_regression.calibrated_new_cases(new_cases=721,calibrated_regression_number=400)
```